#
# spec file for package elisa
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
Name:           elisa
Version:        0.1.1
Release:        lp150.1.1
Summary:        Music player and collection organizer
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
Url:            https://community.kde.org/Elisa
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Baloo) >= 5.41.0
BuildRequires:  cmake(KF5Config) >= 5.41.0
BuildRequires:  cmake(KF5ConfigWidgets) >= 5.41.0
BuildRequires:  cmake(KF5CoreAddons) >= 5.41.0
BuildRequires:  cmake(KF5Crash) >= 5.41.0
BuildRequires:  cmake(KF5DBusAddons) >= 5.41.0
BuildRequires:  cmake(KF5Declarative) >= 5.41.0
BuildRequires:  cmake(KF5DocTools) >= 5.41.0
BuildRequires:  cmake(KF5FileMetaData) >= 5.41.0
BuildRequires:  cmake(KF5I18n) >= 5.41.0
BuildRequires:  cmake(KF5KCMUtils) >= 5.41.0
BuildRequires:  cmake(KF5Package) >= 5.41.0
BuildRequires:  cmake(KF5XmlGui) >= 5.41.0
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Core) >= 5.9.0
BuildRequires:  pkgconfig(Qt5DBus) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Multimedia) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Qml) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Quick) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Sql) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.9.0
Requires:       kdeclarative-components >= 5.41.0
Requires:       libqt5-qtquickcontrols >= 5.9.0
Requires:       libqt5-qtquickcontrols2 >= 5.9.0
%if %{with lang}
Recommends:     %{name}-lang
%endif

%description
Elisa is a music player with a library where music can be browsed by
album, artist or all tracks. It is indexed using either a private
indexer or an indexer using Baloo. The private one can be configured
to scan music on chosen paths. The Baloo one is faster because Baloo
is providing all needed data from its own database. Playlists can be
built and played.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif
  %suse_update_desktop_file -r org.kde.elisa Qt KDE AudioVideo Audio Player

%files
%license COPYING*
%doc README*
%doc %lang(en) %{_kf5_htmldir}/en/elisa/
%{_kf5_bindir}/elisa
%{_kf5_applicationsdir}/org.kde.elisa.desktop
%dir %{_kf5_plugindir}/kcms
%{_kf5_plugindir}/kcms/kcm_elisa_local_file.so
%{_kf5_iconsdir}/hicolor/*/apps/elisa.*
%{_kf5_appstreamdir}/org.kde.elisa.appdata.xml
%dir %{_kf5_sharedir}/kpackage
%dir %{_kf5_sharedir}/kpackage/kcms
%dir %{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file
%dir %{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/contents
%dir %{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/contents/ui
%{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/contents/ui/main.qml
%{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/metadata.desktop
%{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/metadata.json
%{_kf5_sharedir}/kservices5/kcm_elisa_local_file.desktop

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Apr 17 2018 kbabioch@suse.com
- Update to 0.1.1
  * Minor bugfixes
- Download and verify signature for source archive
- Cleaned up spec file (spec-cleaner)
* Sun Apr  8 2018 wbauer@tmo.at
- Update to 0.1
  * First stable release
- Update build requirements
- Add necessary runtime requirements
- Mark license files as %%license instead of %%doc
* Mon Feb  5 2018 jengelh@inai.de
- Ensure neutrality of description.
- Replace vision statement by what the software is about.
* Fri Feb  2 2018 kbabioch@suse.com
- Initial packaging of elisa
